@@ -1,23 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
  * gtksourcecompletionproviderwords.c
- * This file is part of gtksourceview
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom
  *
- * gtksourceview is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * gtksourceview is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * gtksourceview is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with gtksourceview; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, 
- * Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "gtksourcecompletionwords.h"
@@ -29,7 +28,7 @@
 #include <gtksourceview/gtksourceview-i18n.h>
 #include <string.h>
 
-#define GTK_SOURCE_COMPLETION_WORDS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_TYPE_SOURCE_COMPLETION_WORDS, GtkSourceCompletionWordsPrivate))
+#define GTK_SOURCE_COMPLETION_WORDS_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_SOURCE_TYPE_COMPLETION_WORDS, GtkSourceCompletionWordsPrivate))
 
 #define BUFFER_KEY "GtkSourceCompletionWordsBufferKey"
 
@@ -91,13 +90,13 @@ GType gsc_proposal_words_get_type (void);
 G_DEFINE_TYPE_WITH_CODE (GtkSourceCompletionWords,
 			 gtk_source_completion_words,
 			 G_TYPE_OBJECT,
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_SOURCE_COMPLETION_PROVIDER,
+			 G_IMPLEMENT_INTERFACE (GTK_SOURCE_TYPE_COMPLETION_PROVIDER,
 				 		gtk_source_completion_words_iface_init))
 
-static const gchar * 
+static gchar *
 gtk_source_completion_words_get_name (GtkSourceCompletionProvider *self)
 {
-	return GTK_SOURCE_COMPLETION_WORDS (self)->priv->name;
+	return g_strdup (GTK_SOURCE_COMPLETION_WORDS (self)->priv->name);
 }
 
 static GdkPixbuf * 
@@ -174,7 +173,9 @@ add_in_idle (GtkSourceCompletionWords *words)
 	                                             GTK_SOURCE_COMPLETION_PROVIDER (words),
 	                                             ret,
 	                                             finished);
-	
+
+	g_list_free (ret);
+
 	if (finished)
 	{
 		gtk_source_completion_words_library_unlock (words->priv->library);
@@ -270,9 +271,9 @@ gtk_source_completion_words_populate (GtkSourceCompletionProvider *provider,
 	}
 
 	words->priv->cancel_id = 
-		g_signal_connect_swapped (context, 
-			                  "cancelled", 
-			                   G_CALLBACK (population_finished), 
+		g_signal_connect_swapped (context,
+			                  "cancelled",
+			                   G_CALLBACK (population_finished),
 			                   provider);
 
 	words->priv->context = g_object_ref (context);
@@ -490,7 +491,7 @@ gtk_source_completion_words_class_init (GtkSourceCompletionWordsClass *klass)
 	                                                    _("Number of lines scanned in one batch"),
 	                                                    1,
 	                                                    G_MAXUINT,
-	                                                    20,
+	                                                    50,
 	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 	
 	g_object_class_install_property (object_class,
@@ -581,11 +582,18 @@ gtk_source_completion_words_init (GtkSourceCompletionWords *self)
 	self->priv->library = gtk_source_completion_words_library_new ();
 }
 
+/**
+ * gtk_source_completion_words_new:
+ * @name: (allow-none): The name for the provider
+ * @icon: (allow-none): A specific icon for the provider
+ *
+ * Returns: a new #GtkSourceCompletionWords provider
+ */
 GtkSourceCompletionWords *
 gtk_source_completion_words_new (const gchar *name,
                                  GdkPixbuf   *icon)
 {
-	return g_object_new (GTK_TYPE_SOURCE_COMPLETION_WORDS, 
+	return g_object_new (GTK_SOURCE_TYPE_COMPLETION_WORDS, 
 	                     "name", name, 
 	                     "icon", icon, 
 	                     NULL);
@@ -600,6 +608,13 @@ buffer_destroyed (BufferBinding *binding)
 	g_slice_free (BufferBinding, binding);
 }
 
+/**
+ * gtk_source_completion_words_register:
+ * @words: a #GtkSourceCompletionWords
+ * @buffer: a #GtkTextBuffer
+ *
+ * Registers @buffer in the @words provider.
+ */
 void
 gtk_source_completion_words_register (GtkSourceCompletionWords *words,
                                       GtkTextBuffer            *buffer)
@@ -607,7 +622,7 @@ gtk_source_completion_words_register (GtkSourceCompletionWords *words,
 	GtkSourceCompletionWordsBuffer *buf;
 	BufferBinding *binding;
 
-	g_return_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS (words));
+	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS (words));
 	g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
 	
 	binding = g_object_get_data (G_OBJECT (buffer), BUFFER_KEY);
@@ -639,11 +654,18 @@ gtk_source_completion_words_register (GtkSourceCompletionWords *words,
 	                                       binding);
 }
 
+/**
+ * gtk_source_completion_words_unregister:
+ * @words: a #GtkSourceCompletionWords
+ * @buffer: a #GtkTextBuffer
+ *
+ * Unregisters @buffer from teh @words provider.
+ */
 void
 gtk_source_completion_words_unregister (GtkSourceCompletionWords *words,
                                         GtkTextBuffer            *buffer)
 {
-	g_return_if_fail (GTK_IS_SOURCE_COMPLETION_WORDS (words));
+	g_return_if_fail (GTK_SOURCE_IS_COMPLETION_WORDS (words));
 	g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
 	
 	g_object_set_data (G_OBJECT (buffer), BUFFER_KEY, NULL);
